<?php
/*
  $Id: bm_shop_by_price.php
  $Loc: catalog/includes/modules/boxes/

  2020 Shop by Price 5.3.0 CE Phoenix
  by @raiwa
  info@oscaddons.com
  www.oscaddons.com

  Based on:
  Contribution by Meltus  http://www.highbarn-consulting.com
  Adapted for OsCommerce MS2 by Sylvio Ruiz suporte@leilodata.com
  Modified by Hugues Deriau on 09/23/2006 - display the price ranges in the selected currency
  Modified by Glassraven for dropdown list 24/10/2006 www.glassraven.com
  Modified by -GuiGui- (http://www.gpuzin.com) - 07/03/2008 - fix the title and work with the contribution " Product Listing in Columns"

  Copyright (c) 2020 Rainer Schmied
  All rights reserved.

  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

  1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.

  2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.

  3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

  class bm_shop_by_price extends abstract_block_module {

    const CONFIG_KEY_BASE = 'MODULE_BOXES_SHOP_BY_PRICE_';

    function __construct() {
      parent::__construct(__FILE__);

      $this->description .= '<p>by @raiwa <u><a target="_blank" href="http://www.oscaddons.com">www.oscaddons.com</a></u></p>';

    }

    function execute() {
      global $current_category_id, $Linker;

      $price_ranges = [];

      $price_ranges_array = explode(',', constant('MODULE_BOXES_SHOP_BY_PRICE_PRICE_RANGE_' . $_SESSION['currency']));
      $price_ranges[0] =  MODULE_BOXES_SHOP_BY_PRICE_LESS_THAN .  $this->format0($price_ranges_array[0], false);
      for ($price_range=1; $price_range<sizeof($price_ranges_array); $price_range++) {
        $price_ranges[$price_range] = $this->format0($price_ranges_array[$price_range-1], false). " &minus; " . $this->format0($price_ranges_array[$price_range], false);
      }
      $price_ranges[sizeof($price_ranges_array)] =  MODULE_BOXES_SHOP_BY_PRICE_MORE_THAN .  $this->format0($price_ranges_array[sizeof($price_ranges_array)-1], false);
      $price_ranges[sizeof($price_ranges_array)+1] =  MODULE_BOXES_SHOP_BY_PRICE_ALL;

      if (MODULE_BOXES_SHOP_BY_PRICE_DROP_DOWN == 'Dropdown') {
        $price_range_list = [];
        $price_range_list[] = ['id' => '0', 'text' => PULL_DOWN_DEFAULT];

        for ($range=1; $range<sizeof($price_ranges)+1; $range++) {
          $price_range_list[] = ['id' => $range, 'text' => $price_ranges[$range-1]];
        }

        $range = $_GET['range'] ?? null;

        $link = $Linker->build('shop_by_price.php');
        $form = new Form('shop_price', $link, 'get', ['role' => 'form']);
        foreach ((clone $link)->retain_query_except(['range', 'lrange', 'action'])->get_parameters() as $key => $value) {
          $form->hide($key, $value);
        }
      }

        $tpl_data = ['group' => $this->group, 'file' => __FILE__];
        include 'includes/modules/block_template.php';
    }

    protected function get_parameters() {
      $config_parameters = [
        'MODULE_BOXES_SHOP_BY_PRICE_STATUS' => [
          'title' => 'Enable Shop by Price Module',
          'value' => 'True',
          'desc' => 'Do you want to add the module to your shop?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        'MODULE_BOXES_SHOP_BY_PRICE_CONTENT_PLACEMENT' => [
          'title' => 'Content Placement',
          'value' => 'Right Column',
          'desc' => 'Should the module be loaded in the left or right column?',
          'set_func' => "Config::select_one(['Left Column', 'Right Column'], ",
        ],
        'MODULE_BOXES_SHOP_BY_PRICE_SORT_ORDER' => [
          'title' => 'Sort Order',
          'value' => '5200',
          'desc' => 'Sort order of display. Lowest is displayed first.',
        ],
        'MODULE_BOXES_SHOP_BY_PRICE_USE_FAST_TAX_QUERY' => [
          'title' => 'Use fast Tax Query',
          'value' => 'True',
          'desc' => 'Should work for most shops with standard tax settings.<br>Set to false if you have very complicate tax sttings with several Tax zones/types and get missing products in range results.',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        'MODULE_BOXES_SHOP_BY_PRICE_USE_DECIMAL' => [
          'title' => 'Use decimal places',
          'value' => 'False',
          'desc' => 'Do you want to use decimal places for the price ranges?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
      ];
      
      $currencies = new currencies();
      foreach($currencies->currencies as $key => $value) {
        $config_parameters['MODULE_BOXES_SHOP_BY_PRICE_PRICE_RANGE_' . $key] = [
            'title' => 'Price Range  ' . $key,
            'value' => '10,20,30,50,100',
            'desc' => 'Price Range Steps separated by comma for ' . $key . ' currency.<br>Default:"10,20,30,50,100"<br>If decimals, use point for decimal separator. Example: 2.50',
        ];
      }
      $config_parameters['MODULE_BOXES_SHOP_BY_PRICE_DROP_DOWN'] = [
          'title' => 'Ranges in Drop Down or List',
          'value' => 'List',
          'desc' => 'Do you want to use a drop down menu or a list for the price ranges?',
          'set_func' => "Config::select_one(['Dropdown', 'List'], ",
      ];
      
      return $config_parameters;
      
    }

    function format0($number, $currency_type = '', $currency_value = '') {
      global $calculate_currency_value;

      if (empty($currency_type)) $currency_type = $_SESSION['currency'];

      if ( defined('MODULE_BOXES_SHOP_BY_PRICE_USE_DECIMAL') && MODULE_BOXES_SHOP_BY_PRICE_USE_DECIMAL == 'True') {
        if ($calculate_currency_value == true) {
          $rate = (!Text::is_empty($currency_value)) ? $currency_value : $GLOBALS['currencies']->currencies[$currency_type]['value'];
          $format_string = $GLOBALS['currencies']->currencies[$currency_type]['symbol_left'] . number_format(currencies::round($number * $rate, $GLOBALS['currencies']->currencies[$currency_type]['decimal_places']), $GLOBALS['currencies']->currencies[$currency_type]['decimal_places'], $GLOBALS['currencies']->currencies[$currency_type]['decimal_point'], $GLOBALS['currencies']->currencies[$currency_type]['thousands_point']) . $GLOBALS['currencies']->currencies[$currency_type]['symbol_right'];
        } else {
          $format_string = $GLOBALS['currencies']->currencies[$currency_type]['symbol_left'] . number_format(currencies::round($number, $GLOBALS['currencies']->currencies[$currency_type]['decimal_places']), $GLOBALS['currencies']->currencies[$currency_type]['decimal_places'], $GLOBALS['currencies']->currencies[$currency_type]['decimal_point'], $GLOBALS['currencies']->currencies[$currency_type]['thousands_point']) . $GLOBALS['currencies']->currencies[$currency_type]['symbol_right'];
        }
      } else {
        if ($calculate_currency_value == true) {
          $rate = (!Text::is_empty($currency_value)) ? $currency_value : $GLOBALS['currencies']->currencies[$currency_type]['value'];
          $format_string = $GLOBALS['currencies']->currencies[$currency_type]['symbol_left'] . number_format(currencies::round(round($number * $rate, $round_places), $GLOBALS['currencies']->currencies[$currency_type]['decimal_places']), 0, $GLOBALS['currencies']->currencies[$currency_type]['decimal_point'], $GLOBALS['currencies']->currencies[$currency_type]['thousands_point']) . $GLOBALS['currencies']->currencies[$currency_type]['symbol_right'];
        } else {
          $format_string = $GLOBALS['currencies']->currencies[$currency_type]['symbol_left'] . number_format(currencies::round($number, $GLOBALS['currencies']->currencies[$currency_type]['decimal_places']), 0, $GLOBALS['currencies']->currencies[$currency_type]['decimal_point'], $GLOBALS['currencies']->currencies[$currency_type]['thousands_point']) . $GLOBALS['currencies']->currencies[$currency_type]['symbol_right'];
        }
      }

      return $format_string;
    }
  }
